split_apsimx: Split an APSIMX file into separate simulations except...

View source: R/split_apsimx.R

split_apsimxR Documentation

Split an APSIMX file into separate simulations except cultivar

Description

This function takes an APSIMX file and splits it into separate simulations for all factors except cultivar factors. Then saving the results to the specified output location.

Usage

split_apsimx(file, output)

Arguments

file

Character. Path to the input APSIMX file.

output

Character. Path to the directory where the split components will be saved.

Value

No return value. The function is called for its side effects.

Examples

## Not run: 
split_apsimx("path/to/input.apsimx", "path/to/output/directory")

## End(Not run)


rapsimng documentation built on May 6, 2026, 5:06 p.m.