frost_heat_damage: Frost and Heat Damage Functions

frost_heat_damageR Documentation

Frost and Heat Damage Functions

Description

Helper and wrapper functions to calculate frost and heat damage from temperature and growth stage.

Usage

default_frost_heat_params()

stage_sens_frost(growth_stage, params)

stage_sens_heat(growth_stage, params)

temp_damage_frost(mint, params)

temp_damage_heat(maxt, params)

daily_damage_frost(mint, growth_stage, params)

daily_damage_heat(maxt, growth_stage, params)

daily_damage_frost_heat(mint, maxt, growth_stage, params)

cum_damage_frost(mint, growth_stage, params)

cum_damage_heat(maxt, growth_stage, params)

cum_damage_frost_heat(mint, maxt, growth_stage, params)

calc_daily_damage_frost_heat(
  mint,
  maxt,
  growth_stage,
  crop = c("Wheat", "Canola"),
  params = NULL
)

calc_cum_damage_frost_heat(
  mint,
  maxt,
  growth_stage,
  crop = c("Wheat", "Canola"),
  params = NULL
)

Arguments

growth_stage

Numeric vector of daily growth stage.

params

A crop parameter list. If provided, it will override the crop argument.

mint

Numeric vector of daily minimum temperature.

maxt

Numeric vector of daily maximum temperature.

crop

Crop name to use from default_frost_heat_params().

Details

The damage functions are based on the APSIM NG Model FrostHeatDamageFunctions. See full documentation here.

Value

A named list with crop-specific parameter lists.

A numeric vector of frost stage sensitivity (0-1).

A numeric vector of heat stage sensitivity (0-1).

A numeric vector of frost damage contribution from temperature.

A numeric vector of heat damage contribution from temperature.

A numeric vector of daily frost damage.

A numeric vector of daily heat damage.

A numeric vector of combined daily frost and heat damage.

A scalar cumulative frost damage.

A scalar cumulative heat damage.

A scalar cumulative frost and heat damage.

A tibble with daily stage sensitivity, temperature damage, and daily frost/heat/combined damage.

A tibble with cumulative frost damage, cumulative heat damage, and cumulative combined frost-heat damage.

Examples

default_frost_heat_params()
calc_daily_damage_frost_heat(
  mint = c(-2, 0, 4),
  maxt = c(29, 33, 36),
  growth_stage = c(7.0, 8.0, 9.0),
  crop = "Wheat"
)
calc_cum_damage_frost_heat(
  mint = c(-2, 0, 4),
  maxt = c(29, 33, 36),
  growth_stage = c(7.0, 8.0, 9.0),
  crop = "Wheat"
)

rapsimng documentation built on May 6, 2026, 5:06 p.m.