| split_apsimx | R Documentation |
This function takes an APSIMX file and splits it into separate simulations for all factors except cultivar factors. Then saving the results to the specified output location.
split_apsimx(file, output)
file |
Character. Path to the input APSIMX file. |
output |
Character. Path to the directory where the split components will be saved. |
No return value. The function is called for its side effects.
## Not run:
split_apsimx("path/to/input.apsimx", "path/to/output/directory")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.